==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-nb-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nb\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Firma Kontakt Informasjon"

, "Organisation / Unit"
: "Organisasjon / Enhet"

, "Business Address"
: "Firma Adresse"

, "Email"
: "E-Post"

, "Telephone Work"
: "Telefon Jobb"

, "Telephone Cellphone"
: "Telefon Mobil"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Side"

, "URL"
: "URL"

, "Role"
: "Rolle"

, "Room"
: "Rom"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Private Kontakt Detaljer"

, "Private Address"
: "Privat Adresse"

, "Email Home"
: "E-Post Hjem"

, "Telephone Home"
: "Telefon Hjem"

, "Telephone Cellphone Private"
: "Telefon Privat Mobil"

, "Telephone Fax Home"
: "Telefon Fax Hjem"

, "URL Home"
: "URL Hjemme"

, "Other Data"
: "Andre Data"

, "Birthday"
: "Bursdag"

, "Job Title"
: "Jobb Tittel"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "%s's personlige adressebok"

, "Lists"
: "Lister"

, "List Roles"
: ""

, "manage shared addressbooks"
: "organisere delte adressebøker"

, "Create new shared addressbook folders"
: "Opprett nye delte adressebok mapper"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: ""

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: ""

, "Personal Information"
: "Personlig Informasjon"

, "Salutation"
: "Hilsen"

, "Title"
: "Tittel"

, "First Name"
: "Fornavn"

, "Middle Name"
: "Mellom Navn"

, "Last Name"
: "Etternavn"

, "Company"
: "Firma"

, "Unit"
: "Enhet"

, "Suffix"
: "Etternavn"

, "Job Role"
: "Stilling"

, "Display Name"
: "Visnings Navn"

, "Contact Information"
: "Kontakt Informasjon"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privat)"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax (private)"
: "Fax (privat)"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (privat)"

, "Web"
: "Internett"

, "Company Address"
: "Firma Adresse"

, "Street"
: "Gate"

, "Street 2"
: "Gate 2"

, "Region"
: "Sted"

, "Postal Code"
: "Post Nummer"

, "City"
: "By"

, "Country"
: "Land"

, "Description"
: "Beskrivelse"

, "Enter description"
: "Skriv en beskrivelse"

, "Export as pdf"
: "Eksporter som pdf"

, "Parse address"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "New Contact"
: "Ny kontakt"

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "ID"
: ""

, "Name"
: "Navn"

, "Member of List"
: ""

, "Street (Company Address)"
: "Gate (Firma adresse)"

, "Street 2 (Company Address)"
: "Gate 2 (Firma adresse)"

, "City (Company Address)"
: "By (Firma adresse)"

, "Region (Company Address)"
: "Fylke (Firma adresse)"

, "Postal Code (Company Address)"
: "Postnr (Firma adresse)"

, "Country (Company Address)"
: "Land (Firma adresse)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gate (Privat adresse)"

, "Street 2 (Private Address)"
: "Gate 2 (Privat adresse)"

, "City (Private Address)"
: "By (Privat adresse)"

, "Region (Private Address)"
: "Fylke (Privat adresse)"

, "Postal Code (Private Address)"
: "Postnr (Privat adresse)"

, "Country (Private Address)"
: "Land (Privat adresse)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Kontakter"

, "Addressbooks"
: ""

, "User Account"
: "Bruker Konto"

, "Quick Search"
: "Hurtigsøk"

, "Type"
: "Type"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses dato"

, "Created By"
: "Opprettet Av"

, "List, Lists"
: [
  ""
 ,""

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Firma Adresse"

, "Private address"
: "Privat Adresse"

, "Select contact"
: "Velg kontakt"

, "Private"
: "Privat"

, "Info"
: "Informasjon"

, "Insecure link"
: "Usikker link"

, "Please review this link in edit dialog."
: ""

, "Export {0}, Export {0}"
: [
  ""
 ,""

]
, "Export as PDF"
: "Eksporter som PDF"

, "Export as CSV"
: "Eksporter som CSV"

, "Export as ODS"
: "Eksporter som ODS"

, "Export as XLS"
: "Eksporter som XLS"

, "Export as DOC"
: "Eksporter som DOC"

, "Export as ..."
: "Eksporter som"

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Tags"
: "Overskrifter"

, "Full Name"
: "Fullt Navn"

, "Postalcode"
: "Postnummer"

, "Street (private)"
: "Gate (privat)"

, "City (private)"
: "By (privat)"

, "Region (private)"
: "Sted (privat)"

, "Postalcode (private)"
: "Postnummer (privat)"

, "Country (private)"
: "Land (privat)"

, "Car phone"
: "Bil Telefon"

, "Pager"
: "Personsøker"

, "Email (private)"
: "E-Post (Privat)"

, "URL (private)"
: "URL (privat)"

, "Note"
: "Notat"

, "Timezone"
: "Tids sone"

, "Geo"
: "Geo"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: ""

, "All contacts"
: "Alle kontakter"

, "Default Addressbook"
: "Standard Adressebok"

, "The default addressbook for new contacts"
: "Standard adressebok for nye kontakter"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "Standard"

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: "Alle kontakter"

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Herr"

, "Ms"
: "Fru"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "Internal Contacts"
: "Interne Kontakter"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Contact"
: "Kontakt"

, "List Role"
: ""

, "Addressbook"
: ""

, "List"
: ""

, "Email Address"
: ""

, "Export {0}"
: ""

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nb\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Firma Kontakt Informasjon"

, "Organisation / Unit"
: "Organisasjon / Enhet"

, "Business Address"
: "Firma Adresse"

, "Email"
: "E-Post"

, "Telephone Work"
: "Telefon Jobb"

, "Telephone Cellphone"
: "Telefon Mobil"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Side"

, "URL"
: "URL"

, "Role"
: "Rolle"

, "Room"
: "Rom"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Private Kontakt Detaljer"

, "Private Address"
: "Privat Adresse"

, "Email Home"
: "E-Post Hjem"

, "Telephone Home"
: "Telefon Hjem"

, "Telephone Cellphone Private"
: "Telefon Privat Mobil"

, "Telephone Fax Home"
: "Telefon Fax Hjem"

, "URL Home"
: "URL Hjemme"

, "Other Data"
: "Andre Data"

, "Birthday"
: "Bursdag"

, "Job Title"
: "Jobb Tittel"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Beskrivelse"

, "Members"
: ""

, "Type"
: "Type"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Land"

, "City"
: "By"

, "Postalcode"
: "Postnummer"

, "Region"
: "Sted"

, "Street"
: "Gate"

, "Street 2"
: "Gate 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (privat)"

, "City (private)"
: "By (privat)"

, "Postalcode (private)"
: "Postnummer (privat)"

, "Region (private)"
: "Sted (privat)"

, "Street (private)"
: "Gate (privat)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-Post (Privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Notat"

, "Last Name"
: "Etternavn"

, "Display Name"
: "Visnings Navn"

, "Full Name"
: "Fullt Navn"

, "First Name"
: "Fornavn"

, "Middle Name"
: "Mellom Navn"

, "Title"
: "Tittel"

, "Suffix"
: "Etternavn"

, "Company"
: "Firma"

, "Unit"
: "Enhet"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Stilling"

, "Salutation"
: "Hilsen"

, "syncBackendIds"
: ""

, "Car phone"
: "Bil Telefon"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privat)"

, "Phone (private)"
: "Telefon (privat)"

, "Pager"
: "Personsøker"

, "Phone"
: "Telefon"

, "Timezone"
: "Tids sone"

, "Web"
: "Internett"

, "URL (private)"
: "URL (privat)"

, "Label"
: ""

, "Lists"
: "Lister"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kontakt Informasjon"

, "Company Address"
: "Firma Adresse"

, "New Contact"
: "Ny kontakt"

, "ID"
: ""

, "Name"
: "Navn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privat"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Overskrifter"

, "List Roles"
: ""

, "Street (Company Address)"
: "Gate (Firma adresse)"

, "Street 2 (Company Address)"
: "Gate 2 (Firma adresse)"

, "City (Company Address)"
: "By (Firma adresse)"

, "Region (Company Address)"
: "Fylke (Firma adresse)"

, "Postal Code (Company Address)"
: "Postnr (Firma adresse)"

, "Country (Company Address)"
: "Land (Firma adresse)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gate (Privat adresse)"

, "Street 2 (Private Address)"
: "Gate 2 (Privat adresse)"

, "City (Private Address)"
: "By (Privat adresse)"

, "Region (Private Address)"
: "Fylke (Privat adresse)"

, "Postal Code (Private Address)"
: "Postnr (Privat adresse)"

, "Country (Private Address)"
: "Land (Privat adresse)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (privat)"

, "Web (private)"
: ""

, "Contacts"
: "Kontakter"

, "Addressbooks"
: ""

, "User Account"
: "Bruker Konto"

, "Quick Search"
: "Hurtigsøk"

, "Postal Code"
: "Post Nummer"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses dato"

, "Created By"
: "Opprettet Av"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Skriv en beskrivelse"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: ""

, "Company address"
: "Firma Adresse"

, "Private address"
: "Privat Adresse"

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Personlig Informasjon"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Alle kontakter"

, "Default Addressbook"
: "Standard Adressebok"

, "The default addressbook for new contacts"
: "Standard adressebok for nye kontakter"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "Standard"

, "All Contacts"
: "Alle kontakter"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Herr"

, "Ms"
: "Fru"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "organisere delte adressebøker"

, "Create new shared addressbook folders"
: "Opprett nye delte adressebok mapper"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's personlige adressebok"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Interne Kontakter"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Norwegian Bokmål\nX-Poedit-Country: \nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "Kontakt"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
